Improve this doc View Source

Use the `$locationProvider` to configure how the application deep linking paths are stored.

## Methods

- ###

  `hashPrefix([prefix]);`

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  prefix (optional) | string | Prefix for hash part (containing path and search)

  #### Returns

  * | current value if used as getter or itself (chaining) if used as setter

- ###

  `html5Mode([mode]);`

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  mode (optional) | boolean | Use HTML5 strategy if available.

  #### Returns

  * | current value if used as getter or itself (chaining) if used as setter